describe("Playground", function () {
  it("loads", function () {
    cy.visit("/")
    cy.get("h1").should("be.visible")
    cy.get("h2").should("be.visible")
    cy.get("#scrapeButton").should("be.visible")
  })

  it("can scrape", function () {
    cy.visit("/")
    cy.get("#url").type("https://en.wikipedia.org/wiki/Special:Random")
    cy.get(".propertyName").type("title")
    cy.get(".propertySelector").type("h1")
    cy.get("button").contains("+ Add Property").click()
    cy.get(".propertyName").last().type("link")
    cy.get(".propertySelector").last().type("#n-randompage a")
    cy.get(".propertyType").last().select("href")
    cy.get("#scrapeButton").should("be.visible")
    cy.get("#scrapeButton").click()
    cy.get("#responseOutput", { timeout: 40000 })
    cy.get("#responseOutput code").contains('"title":').should("be.visible")
    cy.get("#responseOutput code").contains('"link":').should("be.visible")
    cy.get(".heading")
      .contains("pages/api/getWikipedia.js")
      .should("be.visible")
    cy.get("#codeOutput code").contains("titleSelector =").should("be.visible")
    cy.get("#codeOutput code").contains("linkSelector =").should("be.visible")
    cy.get("#codeOutput code").contains("h1").should("be.visible")
    cy.get("#codeOutput code").contains("#n-randompage").should("be.visible")
    cy.get("#codeOutput code").contains("getWikipedia =").should("be.visible")
    cy.get("#codeOutput code")
      .contains("https://en.wikipedia.org/wiki/Special:Random")
      .should("be.visible")
  })

  describe("Examples", function () {
    it("load Reddit Front Page", function () {
      cy.visit("/")
      cy.get("#selectExample").select("Reddit Front Page")
      cy.get("#url").should("have.value", "https://reddit.com")
      cy.get("#scrapeButton").click()
      cy.get("#responseOutput", { timeout: 40000 })
      cy.get("#responseOutput code").contains('"url":').should("be.visible")
      cy.get("#responseOutput code")
        .contains('"headline":')
        .should("be.visible")
      cy.get(".heading").contains("pages/api/getReddit.js").should("be.visible")
      cy.get("#codeOutput code").contains("urlSelector =").should("be.visible")
      cy.get("#codeOutput code")
        .contains("headlineSelector =")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("a[data-click-id=body]")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("a[data-click-id=body] h3")
        .should("be.visible")
      cy.get("#codeOutput code").contains("getReddit =").should("be.visible")
      cy.get("#codeOutput code")
        .contains("https://reddit.com")
        .should("be.visible")
    })

    // it("load Certified Fresh TV", function () {
    //   cy.get("#selectExample").select("Certified Fresh TV")
    //   cy.get("#url").should(
    //     "have.value",
    //     "https://www.rottentomatoes.com/browse/tv-list-3"
    //   )
    //   cy.get("#scrapeButton").click()
    //   cy.get("#responseOutput", { timeout: 40000 })
    //   cy.get("#responseOutput code").contains('"title":').should("be.visible")
    //   cy.get("#responseOutput code").contains('"score":').should("be.visible")
    //   cy.get(".heading")
    //     .contains("pages/api/getRottentomatoes.js")
    //     .should("be.visible")
    //   cy.get("#codeOutput code")
    //     .contains("titleSelector =")
    //     .should("be.visible")
    //   cy.get("#codeOutput code")
    //     .contains("scoreSelector =")
    //     .should("be.visible")
    //   cy.get("#codeOutput code")
    //     .contains(".mb-movies .movieTitle")
    //     .should("be.visible")
    //   cy.get("#codeOutput code")
    //     .contains(".mb-movies .tMeterScore")
    //     .should("be.visible")
    //   cy.get("#codeOutput code")
    //     .contains("getRottentomatoes =")
    //     .should("be.visible")
    //   cy.get("#codeOutput code")
    //     .contains("https://www.rottentomatoes.com")
    //     .should("be.visible")
    // })

    it("load Trending on Github", function () {
      cy.visit("/")
      cy.get("#selectExample").select("Trending on Github")
      cy.get("#url").should("have.value", "https://github.com/trending")
      cy.get("#scrapeButton").click()
      cy.get("#responseOutput", { timeout: 40000 })
      cy.get("#responseOutput code")
        .contains('"repository":')
        .should("be.visible")
      cy.get("#responseOutput code")
        .contains('"description":')
        .should("be.visible")
      cy.get("#responseOutput code")
        .contains('"language":')
        .should("be.visible")
      cy.get("#responseOutput code").contains('"stars":').should("be.visible")
      cy.get(".heading").contains("pages/api/getGithub.js").should("be.visible")
      cy.get("#codeOutput code")
        .contains("repositorySelector =")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("descriptionSelector =")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("languageSelector =")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("starsSelector =")
        .should("be.visible")
      cy.get("#codeOutput code").contains("getGithub =").should("be.visible")
      cy.get("#codeOutput code")
        .contains("https://github.com")
        .should("be.visible")
    })

    it("load Trending on Twitter", function () {
      cy.visit("/")
      cy.get("#selectExample").select("Trending on Twitter (US)")
      cy.get("#url").should(
        "have.value",
        "https://getdaytrends.com/united-states/"
      )
      cy.get("#scrapeButton").click()
      cy.get("#responseOutput", { timeout: 40000 })
      cy.get("#responseOutput code").contains('"trend":').should("be.visible")
      cy.get("#responseOutput code")
        .contains('"numTweets":')
        .should("be.visible")
      cy.get(".heading")
        .contains("pages/api/getGetdaytrends.js")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("trendSelector =")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("numTweetsSelector =")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("getGetdaytrends =")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("https://getdaytrends.com")
        .should("be.visible")
    })

    it("load Tech Events", function () {
      cy.visit("/")
      cy.get("#selectExample").select("Tech Events")
      cy.get("#url").should("have.value", "https://techevents.online/")
      cy.get("#scrapeButton").click()
      cy.get("#responseOutput", { timeout: 40000 })
      cy.get("#responseOutput code").contains('"link":').should("be.visible")
      cy.get("#responseOutput code").contains('"name":').should("be.visible")
      cy.get("#responseOutput code").contains('"date":').should("be.visible")
      cy.get(".heading")
        .contains("pages/api/getTechevents.js")
        .should("be.visible")
      cy.get("#codeOutput code").contains("linkSelector =").should("be.visible")
      cy.get("#codeOutput code").contains("nameSelector =").should("be.visible")
      cy.get("#codeOutput code").contains("dateSelector =").should("be.visible")
      cy.get("#codeOutput code")
        .contains("getTechevents =")
        .should("be.visible")
      cy.get("#codeOutput code")
        .contains("https://techevents.online/")
        .should("be.visible")
    })
  })
})
